import { supabase } from '@/lib/supabase/config'
import { AuthError } from '@supabase/supabase-js'

export async function signIn(email: string, password: string) {
  try {
    const { data, error } = await supabase.auth.signInWithPassword({
      email,
      password
    })
    if (error) throw error
    return data
  } catch (error) {
    throw handleAuthError(error as AuthError)
  }
}

export async function signUp(email: string, password: string, fullName: string) {
  try {
    const { data, error } = await supabase.auth.signUp({
      email,
      password,
      options: {
        data: { full_name: fullName },
        emailRedirectTo: `${window.location.origin}/auth/callback`
      }
    })
    if (error) throw error
    return data
  } catch (error) {
    throw handleAuthError(error as AuthError)
  }
}

export async function signOut() {
  const { error } = await supabase.auth.signOut()
  if (error) throw handleAuthError(error)
}

function handleAuthError(error: AuthError) {
  console.error('Auth error:', error)
  return {
    message: getErrorMessage(error),
    status: error.status || 500
  }
}

function getErrorMessage(error: AuthError): string {
  switch (error.message) {
    case 'Invalid login credentials':
      return 'Invalid email or password'
    case 'Email not confirmed':
      return 'Please verify your email address'
    case 'Email already registered':
      return 'An account with this email already exists'
    default:
      return error.message || 'An error occurred during authentication'
  }
}